@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import mock
 
@@ -20,7 +20,7 @@ class TestAjaxResponseMixin(TestViewHelper, test.TestCase):
     """
     Tests for AjaxResponseMixin.
     """
-    methods = [u'get', u'post', u'put', u'delete']
+    methods = ['get', 'post', 'put', 'delete']
 
     def test_xhr(self):
         """
@@ -29,9 +29,8 @@ class TestAjaxResponseMixin(TestViewHelper, test.TestCase):
         # AjaxResponseView returns 'AJAX_OK' when requested with XmlHttpRequest
         for m in self.methods:
             fn = getattr(self.client, m)
-            resp = fn(u'/ajax_response/',
-                      HTTP_X_REQUESTED_WITH=u'XMLHttpRequest')
-            assert force_text(resp.content) == u'AJAX_OK'
+            resp = fn('/ajax_response/', HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+            assert force_text(resp.content) == 'AJAX_OK'
 
     def test_not_xhr(self):
         """
@@ -40,18 +39,18 @@ class TestAjaxResponseMixin(TestViewHelper, test.TestCase):
         """
         for m in self.methods:
             fn = getattr(self.client, m)
-            resp = fn(u'/ajax_response/')
-            assert force_text(resp.content) == u'OK'
+            resp = fn('/ajax_response/')
+            assert force_text(resp.content) == 'OK'
 
     def test_fallback_to_normal_methods(self):
         """
         Ajax methods should fallback to normal methods by default.
         """
         test_cases = [
-            (u'get', u'get'),
-            (u'post', u'post'),
-            (u'put', u'get'),
-            (u'delete', u'get'),
+            ('get', 'get'),
+            ('post', 'post'),
+            ('put', 'get'),
+            ('delete', 'get'),
         ]
 
         for ajax_method, fallback in test_cases:
@@ -59,7 +58,7 @@ class TestAjaxResponseMixin(TestViewHelper, test.TestCase):
             m.return_value = HttpResponse()
             req = self.build_request()
             setattr(mixin, fallback, m)
-            fn = getattr(mixin, u"{0}_ajax".format(ajax_method))
+            fn = getattr(mixin, "{0}_ajax".format(ajax_method))
             ret = fn(req, 1, 2, meth=ajax_method)
             # check if appropriate method has been called
             m.assert_called_once_with(req, 1, 2, meth=ajax_method)
@@ -75,8 +74,8 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
 
     def assert_json_response(self, resp, status_code=200):
         self.assertEqual(status_code, resp.status_code)
-        self.assertEqual(u'application/json',
-                         resp[u'content-type'].split(u';')[0])
+        self.assertEqual('application/json',
+                         resp['content-type'].split(';')[0])
 
     def get_content(self, url):
         """
@@ -92,9 +91,9 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         Tests render_json_response() method.
         """
         user = UserFactory()
-        self.client.login(username=user.username, password=u'asdf1234')
-        data = json.loads(self.get_content(u'/simple_json/'))
-        self.assertEqual({u'username': user.username}, data)
+        self.client.login(username=user.username, password='asdf1234')
+        data = json.loads(self.get_content('/simple_json/'))
+        self.assertEqual({'username': user.username}, data)
 
     def test_serialization(self):
         """
@@ -102,14 +101,14 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         using django's serializer framework.
         """
         a1, a2 = [ArticleFactory() for __ in range(2)]
-        data = json.loads(self.get_content(u'/article_list_json/'))
+        data = json.loads(self.get_content('/article_list_json/'))
         self.assertIsInstance(data, list)
         self.assertEqual(2, len(data))
         titles = []
         for row in data:
             # only title has been serialized
-            self.assertEqual(1, len(row[u'fields']))
-            titles.append(row[u'fields'][u'title'])
+            self.assertEqual(1, len(row['fields']))
+            titles.append(row['fields']['title'])
 
         self.assertIn(a1.title, titles)
         self.assertIn(a2.title, titles)
@@ -128,12 +127,12 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         is longer than the normal one.
         """
         user = UserFactory()
-        self.client.login(username=user.username, password=u'asfa')
-        normal_content = self.get_content(u'/simple_json/')
-        self.view_class.json_dumps_kwargs = {u'indent': 2}
-        pretty_content = self.get_content(u'/simple_json/')
-        normal_json = json.loads(u'{0}'.format(normal_content))
-        pretty_json = json.loads(u'{0}'.format(pretty_content))
+        self.client.login(username=user.username, password='asfa')
+        normal_content = self.get_content('/simple_json/')
+        self.view_class.json_dumps_kwargs = {'indent': 2}
+        pretty_content = self.get_content('/simple_json/')
+        normal_json = json.loads('{0}'.format(normal_content))
+        pretty_json = json.loads('{0}'.format(pretty_content))
         self.assertEqual(normal_json, pretty_json)
         self.assertTrue(len(pretty_content) > len(normal_content))
 
@@ -141,25 +140,25 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         """
         Tests setting custom `json_encoder_class` attribute.
         """
-        data = json.loads(self.get_content(u'/simple_json_custom_encoder/'))
-        self.assertEqual({u'numbers': [1, 2, 3]}, data)
+        data = json.loads(self.get_content('/simple_json_custom_encoder/'))
+        self.assertEqual({'numbers': [1, 2, 3]}, data)
 
 
 class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
     view_class = JsonRequestResponseView
-    request_dict = {u'status': u'operational'}
+    request_dict = {'status': 'operational'}
 
     def test_get_request_json_properly_formatted(self):
         """
         Properly formatted JSON requests should result in a JSON object
         """
-        data = json.dumps(self.request_dict).encode(u'utf-8')
+        data = json.dumps(self.request_dict).encode('utf-8')
         response = self.client.post(
-            u'/json_request/',
-            content_type=u'application/json',
+            '/json_request/',
+            content_type='application/json',
             data=data
         )
-        response_json = json.loads(response.content.decode(u'utf-8'))
+        response_json = json.loads(response.content.decode('utf-8'))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response_json, self.request_dict)
 
@@ -168,10 +167,10 @@ class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
         Improperly formatted JSON requests should make request_json == None
         """
         response = self.client.post(
-            u'/json_request/',
+            '/json_request/',
             data=self.request_dict
         )
-        response_json = json.loads(response.content.decode(u'utf-8'))
+        response_json = json.loads(response.content.decode('utf-8'))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response_json, None)
 
@@ -181,10 +180,10 @@ class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
         or None, the client should get a 400 error
         """
         response = self.client.post(
-            u'/json_bad_request/',
+            '/json_bad_request/',
             data=self.request_dict
         )
-        response_json = json.loads(response.content.decode(u'utf-8'))
+        response_json = json.loads(response.content.decode('utf-8'))
         self.assertEqual(response.status_code, 400)
         self.assertEqual(response_json, self.view_class.error_response_dict)
 
@@ -194,9 +193,9 @@ class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
         or None, the client should get a 400 error
         """
         response = self.client.post(
-            u'/json_custom_bad_request/',
+            '/json_custom_bad_request/',
             data=self.request_dict
         )
-        response_json = json.loads(response.content.decode(u'utf-8'))
+        response_json = json.loads(response.content.decode('utf-8'))
         self.assertEqual(response.status_code, 400)
-        self.assertEqual(response_json, {u'error': u'you messed up'})
+        self.assertEqual(response_json, {'error': 'you messed up'})
